@@ -10,7 +10,7 @@ class Notification(models.Model):
     created = models.DateTimeField(auto_now_add=True)
     updated = models.DateTimeField(auto_now=True)
 
-    def __unicode__(self):
+    def __str__(self):
         return self.name
 
     def get_email_list(self):
@@ -23,17 +23,17 @@ class Notification(models.Model):
         for email in self.get_fail():
             try:
                 emails[email]['fail'] = True
-            except KeyError, e:
+            except KeyError:
                 emails[email] = dict()
                 emails[email]['fail'] = True
 
         return emails
 
     def get_success(self):
-        return filter(None, self.success.split(','))
+        return list(filter(None, self.success.split(',')))
 
     def get_fail(self):
-        return filter(None, self.fail.split(','))
+        return list(filter(None, self.fail.split(',')))
 
     def commit_user_success(self):
         return True if '0' in self.commit_user else False
