@@ -1,6 +1,10 @@
 import pycurl
 import certifi
-import StringIO
+
+try:
+    from StringIO import StringIO as _io
+except ImportError:
+    from io import BytesIO as _io
 
 
 class curl_connection(object):
@@ -20,11 +24,12 @@ class curl_connection(object):
 
     def perform(self, url):
         """Perform get request and return respond value"""
-        b = StringIO.StringIO()
+        b = _io()
         self.curl.setopt(self.curl.URL, str(url))
         self.curl.setopt(self.curl.WRITEFUNCTION, b.write)
         self.curl.perform()
-        return b.getvalue()
+        output = b.getvalue()
+        return output.decode('utf-8')
 
     def perform_post(self, url, post):
         """Perform post request"""
